-----------------------------------------------------------
--Search and Replace All as follows:
-- 1) Replace <DB> with the name of the database to create.
--    (Substitute CoffeeMerchant for DB for a new one.)
-- 2) Replace <PATH> with the full path to this file and 
--    others associated with it. Ensure it ends with a 
--    backslash. E.g., C:\MyDatabases\
-----------------------------------------------------------
--
-- Alter the path so the script can find the CSV files
--
DECLARE
   @data_path nvarchar(256);
SELECT @data_path = '<PATH>';
--
IF NOT EXISTS(SELECT * FROM sys.databases
          WHERE name = N'<DB>')
	CREATE DATABASE <DB>
--GO
USE <DB>
--GO
-- =======================================
-- Delete existing tables
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'SaleItem'
         )
  DROP TABLE SaleItem;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Sale'
         )
  DROP TABLE Sale;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'RentItem'
         )
  DROP TABLE RentItem;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Rental'
         )
  DROP TABLE Rental;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Inventory'
         )
  DROP TABLE Inventory;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'ItemModel'
         )
  DROP TABLE ItemModel;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Manufacturer'
         )
  DROP TABLE Manufacturer;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Employee'
         )
  DROP TABLE Employee;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Department'
         )
  DROP TABLE Department;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'CustomerSkill'
         )
  DROP TABLE CustomerSkill;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'Customer'
         )
  DROP TABLE Customer;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'BindingStyle'
         )
  DROP TABLE BindingStyle;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'SkillLevel'
         )
  DROP TABLE SkillLevel;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'SkiBoardStyle'
         )
  DROP TABLE SkiBoardStyle;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'ProductCategory'
         )
  DROP TABLE ProductCategory;
--
IF EXISTS(
  SELECT *
  FROM sys.tables
  WHERE name = N'PaymentMethod'
         )
  DROP TABLE PaymentMethod;

--
--
-- Create tables
--
CREATE TABLE PaymentMethod
(
PaymentMethod nvarchar(50),
     CONSTRAINT pk_PaymentMethod PRIMARY KEY (PaymentMethod)
);

CREATE TABLE ProductCategory
(
Category      nvarchar(50),
CategoryDescription         nvarchar(250) null,
     CONSTRAINT pk_ProductCategory PRIMARY KEY (Category)
);

CREATE TABLE SkiBoardStyle
(
Style         nvarchar(50),
StyleDescription            nvarchar(150) null,
Category      nvarchar(50) null,
     CONSTRAINT pk_SkiBoardStyle PRIMARY KEY (Style),
     CONSTRAINT fk_ProdCatSkiBoardStyle FOREIGN KEY (Category)
        REFERENCES ProductCategory(Category)
        ON DELETE CASCADE
);

CREATE TABLE SkillLevel
(
SkillLevel    int
     DEFAULT 0,
Description   nvarchar(150) null,
     CONSTRAINT pk_SkillLevel PRIMARY KEY (SkillLevel)
);

CREATE TABLE BindingStyle
(
BindingStyle  nvarchar(50),
Description   nvarchar(150) null,
Style         nvarchar(50) null,
     CONSTRAINT pk_BindingStyle PRIMARY KEY (BindingStyle),
     CONSTRAINT fk_SkiBrdStyleBindStyle FOREIGN KEY (Style)
        REFERENCES SkiBoardStyle(Style)
        ON DELETE CASCADE
);

CREATE TABLE Customer
(
CustomerID    int IDENTITY(10000,1),
LastName      nvarchar(50) null,
FirstName     nvarchar(50) null,
Phone         nvarchar(50) null,
EMail         nvarchar(120) null,
Address       nvarchar(50) null,
City          nvarchar(50) null,
State         nvarchar(50) null,
ZIP           nvarchar(50) null,
Gender        nvarchar(50) null
     CHECK (Gender IN ('Female', 'Male', 'Unidentified')),
DateOfBirth   datetime null,
     CONSTRAINT pk_Customer PRIMARY KEY (CustomerID)
);

CREATE TABLE CustomerSkill
(
CustomerID    int
     DEFAULT 0,
Style         nvarchar(50),
SkillLevel    int null
     DEFAULT 0,
SkillComments nvarchar(250) null,
     CONSTRAINT pk_CustomerSkill PRIMARY KEY (CustomerID,Style),
     CONSTRAINT fk_CustomerCustomerSkill FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_SkiBoardStyleCustSkill FOREIGN KEY (Style)
        REFERENCES SkiBoardStyle(Style)
        ON DELETE CASCADE,
     CONSTRAINT fk_SkillLevelCustSkill FOREIGN KEY (SkillLevel)
        REFERENCES SkillLevel(SkillLevel)
        ON DELETE CASCADE
);

CREATE TABLE Department
(
Department    nvarchar(50),
Description   nvarchar(150) null,
     CONSTRAINT pk_Department PRIMARY KEY (Department)
);

CREATE TABLE Employee
(
EmployeeID    int IDENTITY(10000,1),
TaxpayerID    nvarchar(50) null,
LastName      nvarchar(50) null,
FirstName     nvarchar(50) null,
Address       nvarchar(50) null,
Phone         nvarchar(50) null,
City          nvarchar(50) null,
State         nvarchar(50) null,
ZIP           nvarchar(50) null,
Department    nvarchar(50) null,
     CONSTRAINT pk_Employee PRIMARY KEY (EmployeeID),
     CONSTRAINT fk_DepartmentEmployee FOREIGN KEY (Department)
        REFERENCES Department(Department)
        ON DELETE CASCADE
);

CREATE TABLE Manufacturer
(
ManufacturerID  int IDENTITY(10000,1),
Name          nvarchar(50) null,
Address       nvarchar(50) null,
City          nvarchar(50) null,
State         nvarchar(50) null,
ZIP           nvarchar(50) null,
Phone         nvarchar(50) null,
EMail         nvarchar(150) null,
Category      nvarchar(50) null,
     CONSTRAINT pk_Manufacturer PRIMARY KEY (ManufacturerID),
     CONSTRAINT fk_ProdCatManuf FOREIGN KEY (Category)
        REFERENCES ProductCategory(Category)
        ON DELETE NO ACTION
);

CREATE TABLE ItemModel
(
ModelID       nvarchar(50),
ManufacturerID              int
     DEFAULT 0,
Category      nvarchar(50) null,
Color         nvarchar(50) null,
Cost          money null
     DEFAULT 0,
ModelYear     int null
     DEFAULT 0,
Graphics      nvarchar(50) null,
ItemMaterial  nvarchar(50) null,
ListPrice     money null
     DEFAULT 0,
Style         nvarchar(50) null,
SkillLevel    int null,
WeightMax     real null,
WeightMin     real null,
WaistWidth    real null,
EffectiveEdge real null,
BindingStyle  nvarchar(50) null,
RentalRate    money null,
     CONSTRAINT pk_ItemModel PRIMARY KEY (ModelID),
     CONSTRAINT fk_BindingStyleItemModel FOREIGN KEY (BindingStyle)
        REFERENCES BindingStyle(BindingStyle)
        ON DELETE CASCADE,
     CONSTRAINT fk_ManufacturerItemModel FOREIGN KEY (ManufacturerID)
        REFERENCES Manufacturer(ManufacturerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_ProdCatItemModel FOREIGN KEY (Category)
        REFERENCES ProductCategory(Category)
        ON DELETE NO ACTION,
     CONSTRAINT fk_SkiBrdStyleItemModel FOREIGN KEY (Style)
        REFERENCES SkiBoardStyle(Style)
        ON DELETE NO ACTION,
     CONSTRAINT fk_SkillLevelItemModel FOREIGN KEY (SkillLevel)
        REFERENCES SkillLevel(SkillLevel)
        ON DELETE CASCADE
);

CREATE TABLE Inventory
(
SKU           nvarchar(50),
ModelID       nvarchar(50) null,
ItemSize      real null
     DEFAULT 0,
QuantityOnHand              int null
     DEFAULT 0,
     CONSTRAINT pk_Inventory PRIMARY KEY (SKU),
     CONSTRAINT fk_ItemModelInventory FOREIGN KEY (ModelID)
        REFERENCES ItemModel(ModelID)
        ON DELETE CASCADE
);

CREATE TABLE Rental
(
RentID        int IDENTITY(10000,1),
RentDate      datetime null,
CustomerID    int null
     DEFAULT 0,
ExpectedReturn              datetime null,
PaymentMethod nvarchar(50) null,
     CONSTRAINT pk_Rental PRIMARY KEY (RentID),
     CONSTRAINT fk_CustomerRental FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PaymentMethodRental FOREIGN KEY (PaymentMethod)
        REFERENCES PaymentMethod(PaymentMethod)
        ON DELETE CASCADE
);

CREATE TABLE RentItem
(
RentID        int
     DEFAULT 0,
SKU           nvarchar(50),
RentFee       money null
     DEFAULT 0,
ReturnDate    datetime null,
ReturnCondition             nvarchar(150) null,
RepairCharges money null
     DEFAULT 0,
     CONSTRAINT pk_RentItem PRIMARY KEY (RentID,SKU),
     CONSTRAINT fk_InventoryRentItem FOREIGN KEY (SKU)
        REFERENCES Inventory(SKU)
        ON DELETE CASCADE,
     CONSTRAINT fk_RentalRentItem FOREIGN KEY (RentID)
        REFERENCES Rental(RentID)
        ON DELETE CASCADE
);

CREATE TABLE Sale
(
SaleID        int IDENTITY(10000,1),
SaleDate      datetime null,
CustomerID    int null
     DEFAULT 0,
EmployeeID    int null
     DEFAULT 0,
ShipAddress   nvarchar(50) null,
ShipCity      nvarchar(50) null,
ShipState     nvarchar(50) null,
ShipZIP       nvarchar(50) null,
SalesTax      money null
     DEFAULT 0,
PaymentMethod nvarchar(50) null,
     CONSTRAINT pk_Sale PRIMARY KEY (SaleID),
     CONSTRAINT fk_CustomerSale FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_EmployeeSale FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PaymentMethodSale FOREIGN KEY (PaymentMethod)
        REFERENCES PaymentMethod(PaymentMethod)
        ON DELETE CASCADE
);

CREATE TABLE SaleItem
(
SaleID        int
     DEFAULT 0,
SKU           nvarchar(50),
QuantitySold  int null
     DEFAULT 0,
SalePrice     money null
     DEFAULT 0,
     CONSTRAINT pk_SaleItem PRIMARY KEY (SaleID,SKU),
     CONSTRAINT fk_InventorySaleItem FOREIGN KEY (SKU)
        REFERENCES Inventory(SKU)
        ON DELETE CASCADE,
     CONSTRAINT fk_SaleSaleItem FOREIGN KEY (SaleID)
        REFERENCES Sale(SaleID)
        ON DELETE CASCADE
);

--
-- Load table data
--
-- Table 1 PaymentMethod 
--
EXECUTE (N'BULK INSERT PaymentMethod FROM ''' + @data_path + N'PaymentMethod.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 2 ProductCategory 
--
EXECUTE (N'BULK INSERT ProductCategory FROM ''' + @data_path + N'ProductCategory.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 3 SkiBoardStyle 
--
EXECUTE (N'BULK INSERT SkiBoardStyle FROM ''' + @data_path + N'SkiBoardStyle.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 4 SkillLevel 
--
EXECUTE (N'BULK INSERT SkillLevel FROM ''' + @data_path + N'SkillLevel.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 5 BindingStyle 
--
EXECUTE (N'BULK INSERT BindingStyle FROM ''' + @data_path + N'BindingStyle.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 6 Customer 
--
EXECUTE (N'BULK INSERT Customer FROM ''' + @data_path + N'Customer.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- Table 7 CustomerSkill 
--
EXECUTE (N'BULK INSERT CustomerSkill FROM ''' + @data_path + N'CustomerSkill.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 8 Department 
--
EXECUTE (N'BULK INSERT Department FROM ''' + @data_path + N'Department.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 9 Employee 
--
EXECUTE (N'BULK INSERT Employee FROM ''' + @data_path + N'Employee.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 10 Manufacturer 
--
EXECUTE (N'BULK INSERT Manufacturer FROM ''' + @data_path + N'Manufacturer.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 11 ItemModel 
--
EXECUTE (N'BULK INSERT ItemModel FROM ''' + @data_path + N'ItemModel.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 12 Inventory 
--
EXECUTE (N'BULK INSERT Inventory FROM ''' + @data_path + N'Inventory.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 13 Rental 
--
EXECUTE (N'BULK INSERT Rental FROM ''' + @data_path + N'Rental.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 14 RentItem 
--
EXECUTE (N'BULK INSERT RentItem FROM ''' + @data_path + N'RentItem.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 15 Sale 
--
EXECUTE (N'BULK INSERT Sale FROM ''' + @data_path + N'Sale.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
--
-- Table 16 SaleItem 
--
EXECUTE (N'BULK INSERT SaleItem FROM ''' + @data_path + N'SaleItem.csv''
WITH (
    CHECK_CONSTRAINTS,
    CODEPAGE=''ACP'',
    DATAFILETYPE = ''char'',
    FIELDTERMINATOR= '','',
    ROWTERMINATOR = ''\n'',
    KEEPIDENTITY,
    TABLOCK
);');
--
-- ================================================
-- List table names and row counts for confirmation
--
GO
SET NOCOUNT ON
SELECT 'PaymentMethod' "Table", COUNT(*) "Rows" FROM PaymentMethod     UNION
SELECT 'ProductCategory',       COUNT(*)  FROM ProductCategory         UNION
SELECT 'SkiBoardStyle',         COUNT(*)  FROM SkiBoardStyle           UNION
SELECT 'SkillLevel',            COUNT(*)  FROM SkillLevel              UNION
SELECT 'BindingStyle',          COUNT(*)  FROM BindingStyle            UNION
SELECT 'Customer',              COUNT(*)  FROM Customer                UNION
SELECT 'CustomerSkill',         COUNT(*)  FROM CustomerSkill           UNION
SELECT 'Department',            COUNT(*)  FROM Department              UNION
SELECT 'Employee',              COUNT(*)  FROM Employee                UNION
SELECT 'Manufacturer',          COUNT(*)  FROM Manufacturer            UNION
SELECT 'ItemModel',             COUNT(*)  FROM ItemModel               UNION
SELECT 'Inventory',             COUNT(*)  FROM Inventory               UNION
SELECT 'Rental',                COUNT(*)  FROM Rental                  UNION
SELECT 'RentItem',              COUNT(*)  FROM RentItem                UNION
SELECT 'Sale',                  COUNT(*)  FROM Sale                    UNION
SELECT 'SaleItem',              COUNT(*)  FROM SaleItem
ORDER BY 1;
SET NOCOUNT OFF
GO
