CREATE TABLE PaymentMethod
(
PaymentMethod nvarchar(50),
     CONSTRAINT pk_PaymentMethod PRIMARY KEY (PaymentMethod)
);
go
CREATE TABLE ProductCategory
(
Category      nvarchar(50),
CategoryDescription         nvarchar(250) null,
     CONSTRAINT pk_ProductCategory PRIMARY KEY (Category)
);
go
CREATE TABLE SkiBoardStyle
(
Style         nvarchar(50),
StyleDescription            nvarchar(150) null,
Category      nvarchar(50) null,
     CONSTRAINT pk_SkiBoardStyle PRIMARY KEY (Style),
     CONSTRAINT fk_ProdCatSkiBoardStyle FOREIGN KEY (Category)
        REFERENCES ProductCategory(Category)
        ON DELETE CASCADE
);
go
CREATE TABLE SkillLevel
(
SkillLevel    int
     DEFAULT 0,
Description   nvarchar(150) null,
     CONSTRAINT pk_SkillLevel PRIMARY KEY (SkillLevel)
);
go
CREATE TABLE BindingStyle
(
BindingStyle  nvarchar(50),
Description   nvarchar(150) null,
Style         nvarchar(50) null,
     CONSTRAINT pk_BindingStyle PRIMARY KEY (BindingStyle),
     CONSTRAINT fk_SkiBrdStyleBindStyle FOREIGN KEY (Style)
        REFERENCES SkiBoardStyle(Style)
        ON DELETE CASCADE
);
go
CREATE TABLE Customer
(
CustomerID    int IDENTITY(10000,1),
LastName      nvarchar(50) null,
FirstName     nvarchar(50) null,
Phone         nvarchar(50) null,
EMail         nvarchar(120) null,
Address       nvarchar(50) null,
City          nvarchar(50) null,
State         nvarchar(50) null,
ZIP           nvarchar(50) null,
Gender        nvarchar(50) null
     CHECK (Gender IN ('Female', 'Male', 'Unidentified')),
DateOfBirth   datetime null,
     CONSTRAINT pk_Customer PRIMARY KEY (CustomerID)
);
go
CREATE TABLE CustomerSkill
(
CustomerID    int
     DEFAULT 0,
Style         nvarchar(50),
SkillLevel    int null
     DEFAULT 0,
SkillComments nvarchar(250) null,
     CONSTRAINT pk_CustomerSkill PRIMARY KEY (CustomerID,Style),
     CONSTRAINT fk_CustomerCustomerSkill FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_SkiBoardStyleCustSkill FOREIGN KEY (Style)
        REFERENCES SkiBoardStyle(Style)
        ON DELETE CASCADE,
     CONSTRAINT fk_SkillLevelCustSkill FOREIGN KEY (SkillLevel)
        REFERENCES SkillLevel(SkillLevel)
        ON DELETE CASCADE
);
go
CREATE TABLE Department
(
Department    nvarchar(50),
Description   nvarchar(150) null,
     CONSTRAINT pk_Department PRIMARY KEY (Department)
);
go
CREATE TABLE Employee
(
EmployeeID    int IDENTITY(10000,1),
TaxpayerID    nvarchar(50) null,
LastName      nvarchar(50) null,
FirstName     nvarchar(50) null,
Address       nvarchar(50) null,
Phone         nvarchar(50) null,
City          nvarchar(50) null,
State         nvarchar(50) null,
ZIP           nvarchar(50) null,
Department    nvarchar(50) null,
     CONSTRAINT pk_Employee PRIMARY KEY (EmployeeID),
     CONSTRAINT fk_DepartmentEmployee FOREIGN KEY (Department)
        REFERENCES Department(Department)
        ON DELETE CASCADE
);
go
CREATE TABLE Manufacturer
(
ManufacturerID  int IDENTITY(10000,1),
Name          nvarchar(50) null,
Address       nvarchar(50) null,
City          nvarchar(50) null,
State         nvarchar(50) null,
ZIP           nvarchar(50) null,
Phone         nvarchar(50) null,
EMail         nvarchar(150) null,
Category      nvarchar(50) null,
     CONSTRAINT pk_Manufacturer PRIMARY KEY (ManufacturerID),
     CONSTRAINT fk_ProdCatManuf FOREIGN KEY (Category)
        REFERENCES ProductCategory(Category)
        ON DELETE NO ACTION
);
go
CREATE TABLE ItemModel
(
ModelID       nvarchar(50),
ManufacturerID              int
     DEFAULT 0,
Category      nvarchar(50) null,
Color         nvarchar(50) null,
Cost          money null
     DEFAULT 0,
ModelYear     int null
     DEFAULT 0,
Graphics      nvarchar(50) null,
ItemMaterial  nvarchar(50) null,
ListPrice     money null
     DEFAULT 0,
Style         nvarchar(50) null,
SkillLevel    int null,
WeightMax     real null,
WeightMin     real null,
WaistWidth    real null,
EffectiveEdge real null,
BindingStyle  nvarchar(50) null,
RentalRate    money null,
     CONSTRAINT pk_ItemModel PRIMARY KEY (ModelID),
     CONSTRAINT fk_BindingStyleItemModel FOREIGN KEY (BindingStyle)
        REFERENCES BindingStyle(BindingStyle)
        ON DELETE CASCADE,
     CONSTRAINT fk_ManufacturerItemModel FOREIGN KEY (ManufacturerID)
        REFERENCES Manufacturer(ManufacturerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_ProdCatItemModel FOREIGN KEY (Category)
        REFERENCES ProductCategory(Category)
        ON DELETE NO ACTION,
     CONSTRAINT fk_SkiBrdStyleItemModel FOREIGN KEY (Style)
        REFERENCES SkiBoardStyle(Style)
        ON DELETE NO ACTION,
     CONSTRAINT fk_SkillLevelItemModel FOREIGN KEY (SkillLevel)
        REFERENCES SkillLevel(SkillLevel)
        ON DELETE CASCADE
);
go
CREATE TABLE Inventory
(
SKU           nvarchar(50),
ModelID       nvarchar(50) null,
ItemSize      real null
     DEFAULT 0,
QuantityOnHand              int null
     DEFAULT 0,
     CONSTRAINT pk_Inventory PRIMARY KEY (SKU),
     CONSTRAINT fk_ItemModelInventory FOREIGN KEY (ModelID)
        REFERENCES ItemModel(ModelID)
        ON DELETE CASCADE
);
go
CREATE TABLE Rental
(
RentID        int IDENTITY(10000,1),
RentDate      datetime null,
CustomerID    int null
     DEFAULT 0,
ExpectedReturn              datetime null,
PaymentMethod nvarchar(50) null,
     CONSTRAINT pk_Rental PRIMARY KEY (RentID),
     CONSTRAINT fk_CustomerRental FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PaymentMethodRental FOREIGN KEY (PaymentMethod)
        REFERENCES PaymentMethod(PaymentMethod)
        ON DELETE CASCADE
);
go
CREATE TABLE RentItem
(
RentID        int
     DEFAULT 0,
SKU           nvarchar(50),
RentFee       money null
     DEFAULT 0,
ReturnDate    datetime null,
ReturnCondition             nvarchar(150) null,
RepairCharges money null
     DEFAULT 0,
     CONSTRAINT pk_RentItem PRIMARY KEY (RentID,SKU),
     CONSTRAINT fk_InventoryRentItem FOREIGN KEY (SKU)
        REFERENCES Inventory(SKU)
        ON DELETE CASCADE,
     CONSTRAINT fk_RentalRentItem FOREIGN KEY (RentID)
        REFERENCES Rental(RentID)
        ON DELETE CASCADE
);
go
CREATE TABLE Sale
(
SaleID        int IDENTITY(10000,1),
SaleDate      datetime null,
CustomerID    int null
     DEFAULT 0,
EmployeeID    int null
     DEFAULT 0,
ShipAddress   nvarchar(50) null,
ShipCity      nvarchar(50) null,
ShipState     nvarchar(50) null,
ShipZIP       nvarchar(50) null,
SalesTax      money null
     DEFAULT 0,
PaymentMethod nvarchar(50) null,
     CONSTRAINT pk_Sale PRIMARY KEY (SaleID),
     CONSTRAINT fk_CustomerSale FOREIGN KEY (CustomerID)
        REFERENCES Customer(CustomerID)
        ON DELETE CASCADE,
     CONSTRAINT fk_EmployeeSale FOREIGN KEY (EmployeeID)
        REFERENCES Employee(EmployeeID)
        ON DELETE CASCADE,
     CONSTRAINT fk_PaymentMethodSale FOREIGN KEY (PaymentMethod)
        REFERENCES PaymentMethod(PaymentMethod)
        ON DELETE CASCADE
);
go
CREATE TABLE SaleItem
(
SaleID        int
     DEFAULT 0,
SKU           nvarchar(50),
QuantitySold  int null
     DEFAULT 0,
SalePrice     money null
     DEFAULT 0,
     CONSTRAINT pk_SaleItem PRIMARY KEY (SaleID,SKU),
     CONSTRAINT fk_InventorySaleItem FOREIGN KEY (SKU)
        REFERENCES Inventory(SKU)
        ON DELETE CASCADE,
     CONSTRAINT fk_SaleSaleItem FOREIGN KEY (SaleID)
        REFERENCES Sale(SaleID)
        ON DELETE CASCADE
);
go
